@@ -1,15 +1,18 @@
 import atexit
 import configparser
-import os
+from pathlib import Path
 
 from pdbr._pdbr import rich_pdb_klass
 
 try:
     import readline
 except ImportError:
-    from pyreadline import Readline
+    try:
+        from pyreadline import Readline
 
-    readline = Readline()
+        readline = Readline()
+    except ModuleNotFoundError:
+        readline = None
 
 
 def set_history_file(history_file):
@@ -17,7 +20,8 @@ def set_history_file(history_file):
     This is just for Pdb,
     For Ipython, look at RichPdb.pt_init
     """
-
+    if readline is None:
+        return
     try:
         readline.read_history_file(history_file)
         readline.set_history_length(1000)
@@ -52,7 +56,7 @@ def read_config():
         if "store_history" in config["pdbr"]:
             store_history = config["pdbr"]["store_history"]
 
-    history_file = os.path.join(os.path.expanduser("~"), store_history)
+    history_file = str(Path.home() / store_history)
     set_history_file(history_file)
     ipython_history_file = f"{history_file}_ipython"
 
